@@ -41,7 +41,7 @@ class SequentialEventToQuantizedAbjadContainer(core_converters.abc.Converter):
     :param tempo_envelope: Defines the tempo of the converted music. This is an
         :class:`core_events.TempoEnvelope` object which durations are beats and which
         levels are either numbers (that will be interpreted as beats per minute ('BPM'))
-        or :class:`~mutwo.core_parameters.TempoPoint` objects. If no tempo envelope has
+        or :class:`~mutwo.core_parameters.abc.TempoPoint` objects. If no tempo envelope has
         been defined, Mutwo will assume a constant tempo of 1/4 = 120 BPM.
     """
 
@@ -63,8 +63,8 @@ class SequentialEventToQuantizedAbjadContainer(core_converters.abc.Converter):
         if tempo_envelope is None:
             tempo_envelope = core_events.TempoEnvelope(
                 (
-                    (0, core_parameters.TempoPoint(120)),
-                    (0, core_parameters.TempoPoint(120)),
+                    (0, core_parameters.DirectTempoPoint(120)),
+                    (0, core_parameters.DirectTempoPoint(120)),
                 )
             )
 
@@ -103,7 +103,7 @@ class NauertSequentialEventToQuantizedAbjadContainer(
     :param tempo_envelope: Defines the tempo of the converted music. This is an
         :class:`core_events.TempoEnvelope` object which durations are beats and which
         levels are either numbers (that will be interpreted as beats per minute ('BPM'))
-        or :class:`~mutwo.core_parameters.TempoPoint` objects. If no tempo envelope has
+        or :class:`~mutwo.core_parameters.abc.TempoPoint` objects. If no tempo envelope has
         been defined, Mutwo will assume a constant tempo of 1/4 = 120 BPM.
     :param attack_point_optimizer: Optionally the user can pass a
         :class:`nauert.AttackPointOptimizer` object. Attack point optimizer help to
@@ -392,7 +392,7 @@ class LeafMakerSequentialEventToQuantizedAbjadContainer(
     :param tempo_envelope: Defines the tempo of the converted music. This is an
         :class:`core_events.TempoEnvelope` object which durations are beats and which
         levels are either numbers (that will be interpreted as beats per minute ('BPM'))
-        or :class:`~mutwo.core_parameters.TempoPoint` objects. If no tempo envelope
+        or :class:`~mutwo.core_parameters.abc.TempoPoint` objects. If no tempo envelope
         has been defined, Mutwo will assume a constant tempo of 1/4 = 120 BPM.
 
     This method is significantly faster than the
@@ -453,7 +453,7 @@ class LeafMakerSequentialEventToQuantizedAbjadContainer(
             and leaf_or_tuplet.written_duration < fractions.Fraction(1, 4),
             bar,
         )
-        leaf_selection = abjad.select(relevant_bar_items).leaves()
+        leaf_selection = abjad.select.leaves(relevant_bar_items)
         for leaf in leaf_selection:
             offset = abjad.get.timespan(leaf).start_offset - global_offset
             leaf_offset_list.append(offset)
@@ -617,10 +617,10 @@ class LeafMakerSequentialEventToQuantizedAbjadContainer(
         bar_list = []
         for selection in notes_split_by_time_signature_sequence:
             try:
-                bar = abjad.Container(selection.items, simultaneous=False)
+                bar = abjad.Container(selection, simultaneous=False)
             except Exception:
                 bar = abjad.Container(
-                    abjad.mutate.copy(selection).items, simultaneous=False
+                    abjad.mutate.copy(selection), simultaneous=False
                 )
             bar_list.append(bar)
         voice = abjad.Voice(bar_list)
@@ -802,7 +802,7 @@ class _DurationLineBasedQuantizedAbjadContainerMixin(object):
                         abjad.detach(abjad.Tie(), first_element)
 
                     abjad.attach(
-                        abjad.LilyPondLiteral("\\-", format_slot="after"), first_element
+                        abjad.LilyPondLiteral("\\-", site="after"), first_element
                     )
 
                     for indices in abjad_leaves_indices[1:]:
